# Prerequisites 
## Requirements 

In order to deploy Atlassian’s Data Center products, the following is required:

1. An understanding of [Kubernetes](https://kubernetes.io/docs/concepts/overview/what-is-kubernetes/){.external} and [Helm](https://helm.sh/){.external} concepts
2. A Kubernetes cluster, running Kubernetes `v1.19` or later
3. `kubectl` `v1.19` or later, must be compatible with your cluster
4. `helm` `v3.3` or later

## Environment setup 

Before installing the Data Center Helm charts you need to set up your environment:

### Tooling 
The following CLI tools are required

* [Helm](https://helm.sh/docs/intro/install/){.external}
* [kubectl](https://kubernetes.io/docs/tasks/tools/){.external}

### Create and connect to the Kubernetes cluster

* See examples of [provisioning Kubernetes clusters on cloud-based providers](../examples/cluster/CLOUD_PROVIDERS.md).
* In order to install the charts to your Kubernetes cluster, your Kubernetes client config must be configured appropriately, and you must have the necessary permissions.
* It is up to you to set up security policies.

### Provision an Ingress Controller

* See an example of [provisioning an NGINX Ingress Controller](../examples/ingress/CONTROLLERS.md).
* This step is necessary in order to make your Atlassian product available from outside of the Kubernetes cluster after deployment. 
* The Kubernetes project supports and maintains ingress controllers for the major cloud providers including; [AWS](https://github.com/kubernetes-sigs/aws-load-balancer-controller#readme){.external}, [GCE](https://github.com/kubernetes/ingress-gce/blob/master/README.md#readme){.external} and [nginx](https://github.com/kubernetes/ingress-nginx/blob/master/README.md#readme){.external}. There are also a number of open-source [third-party projects available](https://kubernetes.io/docs/concepts/services-networking/ingress-controllers/){.external}.
* Because different Kubernetes clusters use different ingress configurations/controllers, the Helm charts provide [Ingress Object](https://kubernetes.io/docs/concepts/services-networking/ingress/){.external} templates only.
* The Ingress resource provided as part of the Helm charts is geared toward the [NGINX Ingress Controller](https://kubernetes.github.io/ingress-nginx/){.external} and can be configured via the `ingress` stanza in the appropriate `values.yaml` (an alternative controller can be used).
* For more information about the Ingress controller go to the [Ingress section of the configuration guide](CONFIGURATION.md#ingress).

### Provision a database

* See an example of [provisioning databases on cloud-based providers](../examples/database/CLOUD_PROVIDERS.md).
* Must be of a type and version supported by the Data Center product you wish to install:
  
=== "Jira"
      [Supported databases](https://confluence.atlassian.com/adminjiraserver/supported-platforms-938846830.html#Supportedplatforms-Databases){.external}
=== "Confluence"
      [Supported databases](https://confluence.atlassian.com/doc/supported-platforms-207488198.html#SupportedPlatforms-Databases){.external}
=== "Bitbucket"
      [Supported databases](https://confluence.atlassian.com/bitbucketserver/supported-platforms-776640981.html#Supportedplatforms-databasesDatabases){.external}
=== "Crowd"
      [Supported databases](https://confluence.atlassian.com/crowd/supported-platforms-191851.html#SupportedPlatforms-Databases){.external}

* Must be reachable from the product deployed within your Kubernetes cluster. 
* The database service may be deployed within the same Kubernetes cluster as the Data Center product or elsewhere.
* The products need to be provided with the information they need to connect to the database service. Configuration for each product is mostly the same, with some small differences. For more information go to the [Database connectivity section of the configuration guide](CONFIGURATION.md#database-connectivity).

!!!info "Reducing Pod to DB latency" 

      For better performance consider co-locating your database in the Availability Zone (AZ) as your product nodes. Database-heavy operations (e.g. full re-index) become significantly faster when the database is collocated with the Data Center node in the same AZ, however we don't recommend this if you're running critical workloads.

### Configure a shared-home volume
* All of the Data Center products require a shared network filesystem if they are to be operated in multi-node clusters. If no shared filesystem is available, the products can only be operated in single-node configuration.
* Some cloud based options for a shared filesystem include [AWS EFS](https://aws.amazon.com/efs/){.external} and [Azure Files](https://docs.microsoft.com/en-us/azure/storage/files/storage-files-introduction){.external}. You can also stand up your own NFS
* The logical representation of the chosen storage type within Kubernetes can be defined as `PersistentVolumes` with an associated `PersistentVolumeClaims` in a `ReadWriteMany (RWX)` access mode.
* For more information about volumes go to the [Volumes section of the configuration guide](CONFIGURATION.md#volumes). 
* See examples of [creating shared storage](../examples/storage/STORAGE.md).

### Configure local-home volume
* As with the [shared-home](#configure-a-shared-home-volume) each pod requires its own volume for `local-home`. This is needed by each product for defining operational data. 
* If not defined, an [emptyDir{}](https://kubernetes.io/docs/concepts/storage/volumes/#emptydir){.external} will be utilised. 
* Whilst an `emptyDir` may be acceptable for evaluation purposes it is recommended that each Pod is allocated it's own volume
* A `local-home` volume could be logically represented within the cluster using a `StorageClass`. This will dynamically provision an [AWS EBS](https://aws.amazon.com/ebs/?ebs-whats-new.sort-by=item.additionalFields.postDateTime&ebs-whats-new.sort-order=desc){.external} volume to each Pod. An example of this strategy can be found [here](../examples/storage/aws/LOCAL_STORAGE.md)